@@ -190,11 +190,16 @@ class Spec:
 
         # Deal with further <pre> blocks, and markdown
         self.lines = datablocks.transformDataBlocks(self, self.lines)
+
+        markdownFeatures: set[str] = {"headings"}
+        if "mixed-indents" in self.md.complainAbout:
+            markdownFeatures.add("lint-indentation")
         self.lines = markdown.parse(
             self.lines,
             self.md.indent,
             opaqueElements=self.md.opaqueElements,
             blockElements=self.md.blockElements,
+            features=markdownFeatures,
         )
 
         self.refs.setSpecData(self.md)
@@ -874,6 +879,14 @@ a.self-link:hover {
 .heading > a.self-link {
     font-size: 83%;
 }
+.example > a.self-link,
+.note > a.self-link,
+.issue > a.self-link {
+    /* These blocks are overflow:auto, so positioning outside
+       doesn't work. */
+    left: auto;
+    right: 0;
+}
 li > a.self-link {
     left: calc(-1 * (3.5rem - 26px) - 2em);
 }
