@@ -88,7 +88,10 @@ def tokenizeLines(
     # Every token *must* have 'type', 'raw', and 'prefix' keys.
 
     if features is None:
-        features = {"headings"}
+        features = {"headings", "lint-indentation"}
+
+    featureHeadings = "headings" in features
+    featureLintIndentation = "lint-indentation" in features
 
     if opaqueElements is None:
         opaqueElements = []
@@ -153,6 +156,8 @@ def tokenizeLines(
     rawStack: list[RawTokenT] = []
     rawElements = "|".join(re.escape(x) for x in opaqueElements)
 
+    indentChar: str | None = None
+
     for i, line in enumerate(lines):
 
         # Three kinds of "raw" elements, which prevent markdown processing inside of them.
@@ -229,6 +234,12 @@ def tokenizeLines(
             tokens.append({"type": "raw", "prefixlen": float("inf"), "line": line})
             continue
 
+        if featureLintIndentation:
+            if indentChar is None:
+                indentChar = getIndentChar(line)
+            if indentChar is not None:
+                checkForMixedIndents(line, indentChar)
+
         lineText = line.text.strip()
 
         token: TokenT
@@ -238,15 +249,15 @@ def tokenizeLines(
                 "type": "blank",
             }
         # FIXME: Detect the heading ID from heading lines
-        elif "headings" in features and re.match(r"={3,}\s*$", lineText):
+        elif featureHeadings and re.match(r"={3,}\s*$", lineText):
             # h1 underline
             match = re.match(r"={3,}\s$", lineText)
             token = {"type": "equals-line"}
-        elif "headings" in features and re.match(r"-{3,}\s*$", lineText):
+        elif featureHeadings and re.match(r"-{3,}\s*$", lineText):
             # h2 underline
             match = re.match(r"-{3,}\s*$", lineText)
             token = {"type": "dash-line"}
-        elif "headings" in features and re.match(r"(#{1,5})\s+(.+?)(\1\s*\{#[^ }]+\})?\s*$", lineText):
+        elif featureHeadings and re.match(r"(#{1,5})\s+(.+?)(\1\s*\{#[^ }]+\})?\s*$", lineText):
             # single-line heading
             match = re.match(r"(#{1,5})\s+(.+?)(\1\s*\{#[^ }]+\})?\s*$", lineText)
             assert match is not None
@@ -364,6 +375,27 @@ def stripCommentsFromLine(line: str, inComment: bool = False) -> tuple[str, bool
             return pre + res, inComment
 
 
+def getIndentChar(line: l.Line) -> str | None:
+    if not line.text:
+        return None
+    if line.text[0] in ("\t", " "):
+        return line.text[0]
+    return None
+
+
+def checkForMixedIndents(line: l.Line, indentChar: str) -> None:
+    if not line.text:
+        return
+    badIndentChar = " " if indentChar == "\t" else "\t"
+    if line.text.startswith(badIndentChar):
+        if indentChar == " ":
+            m.lint(f"Your document appears to use spaces to indent, but line {line.i} starts with tabs.")
+        else:
+            m.lint(f"Your document appears to use tabs to indent, but line {line.i} starts with spaces.")
+    if re.match(r"(\t+ )|( +\t)", line.text):
+        m.lint(f"Line {line.i} is indented with both tabs and spaces.")
+
+
 def prefixCount(text: str, numSpacesForIndentation: int) -> int:
     i = 0
     prefixLen = 0
